<?php
/**
 * Plugin Name: GDPR-Extensions-com-Youtube-2ClickSolution
 * Plugin URI: https://www.gdpr-extensions.com/our-plugins/youtube/
 * Description: The GDPR Youtube 2 Click Solution, brought to you by GDPR-Extensions-com, is a feature-rich solution designed to empower website owners in effectively managing youtube videos and bolstering user privacy.
 * Version: 1.0.0
 * Requires at least: 5.9
 * Requires PHP: 7.2
 * Author: GDPR-extensions.com Team
 * Author URI: GDPR-extensions.com
 * License: GPLv2 or later
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 * Text Domain: gdpr-extensions-com-youtube-2clicksolution
 * Domain Path: /languages
 */
/*
This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, GDPR., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

Copyright 2005-2015 Automattic, GDPR.
*/

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

if ( ! function_exists( 'add_action' ) ) {
	echo 'Seems like you have an old version of PHP';
	exit;
}

// Setup
define( 'GDPREXTENSIONCOMYT_PLUGIN_DIR', plugin_dir_path( __FILE__ ) );
define( 'GDPREXTENSIONCOMYT_TEXT_DOMAIN', 'gdpr-youtube-plugin' );


// Hooks
add_action( 'init', 'gdprextensioncomyt_register_blocks' );
add_filter( 'upload_mimes', 'gdprextensioncomyt_svg_to_upload_mimes', 10, 1 );

// Check if the SVG MIME type is already added before adding it
if ( ! function_exists( 'gdprextensioncomyt_svg_to_upload_mimes' ) ) {
	function gdprextensioncomyt_svg_to_upload_mimes( $upload_mimes ) {
		$upload_mimes['svg'] = 'image/svg+xml';
		return $upload_mimes;
	}
	add_filter( 'upload_mimes', 'gdprextensioncomyt_svg_to_upload_mimes', 10, 1 );
}

//Manger Tab 
if ( ! class_exists( 'GDPREXTENSIONCOMYT_Manager_Tab' ) ) {
	class GDPREXTENSIONCOMYT_Manager_Tab {
        private static $scripts_enqueued = false;
        public function __construct()
        {
            $this->gdprextensioncomyt_define_constants();
            $this->gdprextensioncomyt_load_textdomain();

            if (!self::$scripts_enqueued) {

                add_action('admin_enqueue_scripts', array($this, 'gdprextensioncomyt_register_admin_scripts'));
                self::$scripts_enqueued = true;
            }

            add_action('admin_menu', array($this, 'gdprextensioncomyt_plugin_menu'));
            require_once(GDPREXTENSIONCOMYT_Manager_Tab_PATH . 'post-types/class.manager-tab-cpt.php');
            $GDPREXTENSIONCOMYT_Manager_Tab_Post_Type = new GDPREXTENSIONCOMYT_Manager_Tab_Post_Type();
            require_once(GDPREXTENSIONCOMYT_Manager_Tab_PATH . 'views/class.tab-manager-setting.php');
            $GDPREXTENSIONCOMYT_Manager_Tab_Setting = new GDPREXTENSIONCOMYT_Manager_Tab_Setting();
            register_activation_hook(__FILE__, 'gdprextensioncomyt_tabManager_table');
            require_once(GDPREXTENSIONCOMYT_Manager_Tab_PATH . 'functions/functions.php');
			require_once(GDPREXTENSIONCOMYT_Manager_Tab_PATH . 'functions/tabs_data.php');
			
        }

		public function gdprextensioncomyt_define_constants() {
			define( 'GDPREXTENSIONCOMYT_Manager_Tab_PATH', plugin_dir_path( __FILE__ ) );
			define( 'GDPREXTENSIONCOMYT_Manager_Tab_URL', plugin_dir_url( __FILE__ ) );
			define( 'GDPREXTENSIONCOMYT_Manager_Tab_VERSION', '1.0.0' );
		}


		public static function gdprextensioncomyt_activate() {
			$gdprextensioncomyt_plugin_option_name = 'gdpr_extensions_managertab_activated';

			if ( get_option( $gdprextensioncomyt_plugin_option_name ) ) {
				return;
			}

			update_option( 'gdprextensioncomyt_rewrite_rules', '' );
			update_option( $gdprextensioncomyt_plugin_option_name, true );
		}

		public static function gdprextensioncomyt_deactivate() {
			flush_rewrite_rules();
		}


		public function gdprextensioncomyt_load_textdomain() {
			load_plugin_textdomain(
				'gdpr-extensions-com-youtube-2clicksolution',
				false,
				dirname( plugin_basename( __FILE__ ) ) . '/languages/'
			);
		}

		public function gdprextensioncomyt_plugin_menu() {
			add_menu_page(
				esc_html__( 'GDPR-Extensions-Manager-Tab Options', 'gdpr-extensions-com-youtube-2clicksolution' ),
				'GDPR Extensions Tab-Manager',
				'manage_options',
				'managertab_admin',
				array( $this, 'gdprextensioncomyt_managertab_settings_page' )
			);
		}

		public function gdprextensioncomyt_managertab_settings_page() {
			if ( isset( $_POST['gdprextensioncomyt_cookie_nonce'] ) ){
				if (!wp_verify_nonce($_POST['gdprextensioncomyt_cookie_nonce'], 'gdprextensioncomyt_cookie_nonce_action')) {
					return;
				}
			}	
			if (defined ('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
				return;
			}
			if ( ! current_user_can( 'manage_options' ) ) {
				wp_send_json_error( 'Unauthorized access' );
				return;
			}
			if ( isset( $_GET['settings-updated'] ) && $_GET['settings-updated'] ) {
			  add_settings_error( 'gdprextensioncomyt_managertab_content_style', 'gdprextensioncomyt_managertab_message', esc_html__( 'Settings saved', 'gdpr-extensions-com-youtube-2clicksolution' ), 'success' );
			}	
			settings_errors( 'gdprextensioncomyt_managertab_content_style' );
			require( GDPREXTENSIONCOMYT_Manager_Tab_PATH . 'views/tab-setthing-page.php' );
		}

		public function gdprextensioncomyt_register_admin_scripts() {

			wp_enqueue_script( 'manager-tab-tabsAdmin-js', GDPREXTENSIONCOMYT_Manager_Tab_URL . 'assets/js/tabsAdmin.js', array( 'jquery' ), GDPREXTENSIONCOMYT_Manager_Tab_VERSION, false );
			wp_enqueue_script( 'manager-tab-admin-js', GDPREXTENSIONCOMYT_Manager_Tab_URL . 'assets/js/admin.js', array( 'jquery' ), GDPREXTENSIONCOMYT_Manager_Tab_VERSION, false );
			wp_enqueue_script( 'manager-tab-min-js', GDPREXTENSIONCOMYT_Manager_Tab_URL . 'assets/js/min.js', array( 'jquery' ), GDPREXTENSIONCOMYT_Manager_Tab_VERSION, true );
			wp_enqueue_style( 'manager-tab-admin', GDPREXTENSIONCOMYT_Manager_Tab_URL . 'assets/css/admin.css', array(), GDPREXTENSIONCOMYT_Manager_Tab_VERSION );
		}
	}

	function gdprextensioncomyt_tabManager_table() {
		
		global $wpdb;
		$table_name = $wpdb->prefix . 'tab_manager_table';
		$charset_collate = $wpdb->get_charset_collate();

		$sql = "CREATE TABLE $table_name (
            id mediumint(9) NOT NULL AUTO_INCREMENT,
            plugin varchar(255) NOT NULL,
            headline varchar(255) NOT NULL,
            overlay_text text NOT NULL,
            button_text varchar(255) NOT NULL,
            text_color varchar(7) NOT NULL, 
            button_color varchar(7) NOT NULL,
            button_background_color varchar(7) NOT NULL,
            button_radius int NOT NULL,
            show_background varchar(255) NOT NULL,
            overlay_mode varchar(20) NOT NULL,
            background_color varchar(7) NOT NULL,
            image_url varchar(255) NOT NULL,
			google_api_key varchar(255) NOT NULL,
			gtm_code varchar(255) NOT NULL,
			google_tag_manager varchar(255) NOT NULL,
			tracking_code TEXT,
			matomo_code varchar(255) NOT NULL,
            PRIMARY KEY (id)
        ) $charset_collate;";

		require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
		dbDelta( $sql );
	}


	if ( class_exists( 'GDPREXTENSIONCOMYT_Manager_Tab' ) ) {
		$gdprextensioncomyt_managertab = new GDPREXTENSIONCOMYT_Manager_Tab();
		register_activation_hook( __FILE__, array( 'GDPREXTENSIONCOMYT_Manager_Tab', 'gdprextensioncomyt_activate' ) );
		register_deactivation_hook( __FILE__, array( 'GDPREXTENSIONCOMYT_Manager_Tab', 'gdprextensioncomyt_deactivate' ) );
	}
}

//Cookie
if ( ! class_exists( 'GDPREXTENSIONCOMYT_GDPR_Cookie' ) ) {
	class GDPREXTENSIONCOMYT_GDPR_Cookie {
		public function __construct() {
			$this->gdprextensioncomyt_define_constants();
			register_activation_hook( __FILE__, 'gdprextensioncomyt_cookie_table' );
			add_action( 'wp_enqueue_scripts', array( $this, 'gdprextensioncomyt_enqueue_scripts' ) );
			add_action( 'wp_head', array( $this, 'gdprextensioncomyt_enqueue_styles' ) ); 
			require_once( GDPREXTENSIONCOMYT_Cookie_PATH . 'gdpr-extensions-com-cookiewidget/class.tab-cookie-setting.php' );
			$GDPREXTENSIONCOMYT_GDPR_Cookie_Setting = new GDPREXTENSIONCOMYT_GDPR_Cookie_Setting();
		}

		public function gdprextensioncomyt_enqueue_styles() {
			wp_enqueue_style( 'gdpr-cookie-style', GDPREXTENSIONCOMYT_Cookie_URL . 'gdpr-extensions-com-cookiewidget/css/gdpr-cookie-style.css', array(), GDPREXTENSIONCOMYT_Cookie_VERSION );
		}

		public function gdprextensioncomyt_define_constants() {
			define( 'GDPREXTENSIONCOMYT_Cookie_PATH', plugin_dir_path( __FILE__ ) );
			define( 'GDPREXTENSIONCOMYT_Cookie_URL', plugin_dir_url( __FILE__ ) );
			define( 'GDPREXTENSIONCOMYT_Cookie_VERSION', '1.0.0' );
		}

		public function gdprextensioncomyt_activate() {
			$gdprextensioncomyt_plugin_option_name = 'gdpr_extensions_gdpr_cookie_activated';

			if ( ! get_option( $gdprextensioncomyt_plugin_option_name ) ) {
				update_option( 'gdprextensioncomyt_rewrite', '' );
				update_option( $gdprextensioncomyt_plugin_option_name, true );
			}
		}

		public static function gdprextensioncomyt_deactivate() {
			flush_rewrite_rules();
			global $wpdb;
			$table_name = $wpdb->prefix . 'gdpr_cookie';
			$plugin_name = plugin_basename( __FILE__ );
			$cache_key = 'gdprextensioncomyt_cookie_data';
			// @codingStandardsIgnoreStart
			$deleted = $wpdb->delete( $table_name, array( 'plugin' => $plugin_name ), array( '%s' ) ); //db call ok; no-cache ok
			// @codingStandardsIgnoreEnd

			if ( $deleted !== false ) {
				wp_cache_delete( $cache_key );
			}
			
		}

		public function gdprextensioncomyt_enqueue_scripts() {
			wp_enqueue_script( 'gdpr-cookie-script', GDPREXTENSIONCOMYT_Cookie_URL . 'gdpr-extensions-com-cookiewidget/js/gdpr-cookie-script.js', array( 'jquery' ), GDPREXTENSIONCOMYT_Cookie_VERSION, true );
			wp_localize_script(
				'gdpr-cookie-script',
				'gdprCookieSettings',
				array(
					'ajaxurl' => admin_url( 'admin-ajax.php' ),
				)
			);
		}

		
	}

	if ( class_exists( 'GDPREXTENSIONCOMYT_GDPR_Cookie' ) ) {
		$gdpr_cookie = new GDPREXTENSIONCOMYT_GDPR_Cookie();
		register_activation_hook( __FILE__, array( $gdpr_cookie, 'gdprextensioncomyt_activate' ) );
		register_deactivation_hook( __FILE__, array( 'GDPREXTENSIONCOMYT_GDPR_Cookie', 'gdprextensioncomyt_deactivate' ) );
	}


	function gdprextensioncomyt_cookie_table() {
		global $wpdb;

		$table_name = $wpdb->prefix . 'gdpr_cookie';
		$charset_collate = $wpdb->get_charset_collate();

		$sql = "CREATE TABLE $table_name (
        id mediumint(9) NOT NULL AUTO_INCREMENT,
        plugin varchar(255) NOT NULL,
        cookie_text text NOT NULL,
        PRIMARY KEY (id)
    ) $charset_collate;";

		require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
		dbDelta( $sql );
	}

}

// Includes
include( GDPREXTENSIONCOMYT_PLUGIN_DIR . 'includes/youtube-functions.php' );
include( GDPREXTENSIONCOMYT_PLUGIN_DIR . 'includes/register-blocks.php' );
